@@ -11,13 +11,6 @@ class PatternError(MasqueError):
     """
     pass
 
-class PatternLockedError(PatternError):
-    """
-    Exception raised when trying to modify a locked pattern
-    """
-    def __init__(self):
-        PatternError.__init__(self, 'Tried to modify a locked Pattern, subpattern, or shape')
-
 
 class LibraryError(MasqueError):
     """
@@ -26,15 +19,21 @@ class LibraryError(MasqueError):
     pass
 
 
-class DeviceError(MasqueError):
-    """
-    Exception raised by Device and Port objects
-    """
-    pass
-
-
 class BuildError(MasqueError):
     """
     Exception raised by builder-related functions
     """
     pass
+
+class PortError(MasqueError):
+    """
+    Exception raised by builder-related functions
+    """
+    pass
+
+class OneShotError(MasqueError):
+    """
+    Exception raised when a function decorated with `@oneshot` is called more than once
+    """
+    def __init__(self, func_name: str) -> None:
+        Exception.__init__(self, f'Function "{func_name}" with @oneshot was called more than once')
