@@ -1,4 +1,3 @@
-from typing import TypeVar
 #from types import MappingProxyType
 from abc import ABCMeta, abstractmethod
 
@@ -6,20 +5,19 @@ from ..utils import annotations_t
 from ..error import MasqueError
 
 
-T = TypeVar('T', bound='Annotatable')
-I = TypeVar('I', bound='AnnotatableImpl')
+_empty_slots = ()     # Workaround to get mypy to ignore intentionally empty slots for superclass
 
 
 class Annotatable(metaclass=ABCMeta):
     """
-    Abstract class for all annotatable entities
+    Trait class for all annotatable entities
     Annotations correspond to GDS/OASIS "properties"
     """
     __slots__ = ()
 
-    '''
-    ---- Properties
-    '''
+    #
+    # Properties
+    #
     @property
     @abstractmethod
     def annotations(self) -> annotations_t:
@@ -33,23 +31,20 @@ class AnnotatableImpl(Annotatable, metaclass=ABCMeta):
     """
     Simple implementation of `Annotatable`.
     """
-    __slots__ = ()
+    __slots__ = _empty_slots
 
     _annotations: annotations_t
     """ Dictionary storing annotation name/value pairs """
 
-    '''
-    ---- Non-abstract properties
-    '''
+    #
+    # Non-abstract properties
+    #
     @property
     def annotations(self) -> annotations_t:
         return self._annotations
-#        # TODO: Find a way to make sure the subclass implements Lockable without dealing with diamond inheritance or this extra hasattr
-#        if hasattr(self, 'is_locked') and self.is_locked():
-#            return MappingProxyType(self._annotations)
 
     @annotations.setter
-    def annotations(self, annotations: annotations_t):
+    def annotations(self, annotations: annotations_t) -> None:
         if not isinstance(annotations, dict):
             raise MasqueError(f'annotations expected dict, got {type(annotations)}')
         self._annotations = annotations
