@@ -1,21 +1,17 @@
-from typing import TypeVar
-from abc import ABCMeta
+from typing import Self
 import copy
 
 
-T = TypeVar('T', bound='Copyable')
-
-
-class Copyable(metaclass=ABCMeta):
+class Copyable:
     """
-    Abstract class which adds .copy() and .deepcopy()
+    Trait class which adds .copy() and .deepcopy()
     """
     __slots__ = ()
 
-    '''
-    ---- Non-abstract methods
-    '''
-    def copy(self: T) -> T:
+    #
+    # Non-abstract methods
+    #
+    def copy(self) -> Self:
         """
         Return a shallow copy of the object.
 
@@ -24,7 +20,7 @@ class Copyable(metaclass=ABCMeta):
         """
         return copy.copy(self)
 
-    def deepcopy(self: T) -> T:
+    def deepcopy(self) -> Self:
         """
         Return a deep copy of the object.
 
