@@ -1,21 +1,21 @@
-from typing import TypeVar
+from typing import Self
 from abc import ABCMeta, abstractmethod
 
 from ..utils import layer_t
 
 
-T = TypeVar('T', bound='Layerable')
-I = TypeVar('I', bound='LayerableImpl')
+_empty_slots = ()     # Workaround to get mypy to ignore intentionally empty slots for superclass
 
 
 class Layerable(metaclass=ABCMeta):
     """
-    Abstract class for all layerable entities
+    Trait class for all layerable entities
     """
     __slots__ = ()
-    '''
-    ---- Properties
-    '''
+
+    #
+    # Properties
+    #
     @property
     @abstractmethod
     def layer(self) -> layer_t:
@@ -29,10 +29,11 @@ class Layerable(metaclass=ABCMeta):
 #    def layer(self, val: layer_t):
 #        pass
 
-    '''
-    ---- Methods
-    '''
-    def set_layer(self: T, layer: layer_t) -> T:
+    #
+    # Methods
+    #
+    @abstractmethod
+    def set_layer(self, layer: layer_t) -> Self:
         """
         Set the layer
 
@@ -49,25 +50,25 @@ class LayerableImpl(Layerable, metaclass=ABCMeta):
     """
     Simple implementation of Layerable
     """
-    __slots__ = ()
+    __slots__ = _empty_slots
 
     _layer: layer_t
     """ Layer number, pair, or name """
 
-    '''
-    ---- Non-abstract properties
-    '''
+    #
+    # Non-abstract properties
+    #
     @property
     def layer(self) -> layer_t:
         return self._layer
 
     @layer.setter
-    def layer(self, val: layer_t):
+    def layer(self, val: layer_t) -> None:
         self._layer = val
 
-    '''
-    ---- Non-abstract methods
-    '''
-    def set_layer(self: I, layer: layer_t) -> I:
+    #
+    # Non-abstract methods
+    #
+    def set_layer(self, layer: layer_t) -> Self:
         self.layer = layer
         return self
