@@ -1,25 +1,24 @@
-from typing import TypeVar
+from typing import Self
 from abc import ABCMeta, abstractmethod
 
 from ..error import MasqueError
 from ..utils import is_scalar
 
 
-T = TypeVar('T', bound='Scalable')
-I = TypeVar('I', bound='ScalableImpl')
+_empty_slots = ()     # Workaround to get mypy to ignore intentionally empty slots for superclass
 
 
 class Scalable(metaclass=ABCMeta):
     """
-    Abstract class for all scalable entities
+    Trait class for all scalable entities
     """
     __slots__ = ()
 
-    '''
-    ---- Abstract methods
-    '''
+    #
+    # Methods
+    #
     @abstractmethod
-    def scale_by(self: T, c: float) -> T:
+    def scale_by(self, c: float) -> Self:
         """
         Scale the entity by a factor
 
@@ -36,34 +35,34 @@ class ScalableImpl(Scalable, metaclass=ABCMeta):
     """
     Simple implementation of Scalable
     """
-    __slots__ = ()
+    __slots__ = _empty_slots
 
     _scale: float
     """ scale factor for the entity """
 
-    '''
-    ---- Properties
-    '''
+    #
+    # Properties
+    #
     @property
     def scale(self) -> float:
         return self._scale
 
     @scale.setter
-    def scale(self, val: float):
+    def scale(self, val: float) -> None:
         if not is_scalar(val):
             raise MasqueError('Scale must be a scalar')
         if not val > 0:
             raise MasqueError('Scale must be positive')
         self._scale = val
 
-    '''
-    ---- Methods
-    '''
-    def scale_by(self: I, c: float) -> I:
+    #
+    # Methods
+    #
+    def scale_by(self, c: float) -> Self:
         self.scale *= c
         return self
 
-    def set_scale(self: I, scale: float) -> I:
+    def set_scale(self, scale: float) -> Self:
         """
         Set the sclae to a value
 
